@@ -62,13 +62,13 @@ class DataTable(WidgetWrapper):
                     // fix the issue of horizontal scrolling (the size goes beyond the border as jupyter set overflow
                     // to be visible)
                     // DOM structure (* is the one we need to modify)
-                    // jp-Cell-outputArea
-                    // jp-OutputArea-child
-                    // jp-OutputArea-output *
-                    // widgets-output *
-                    // jp-OutputArea *
-                    // jp-OutputArea-child
-                    // jp-OutputArea-output *
+                    //     jp-Cell-outputArea
+                    //     jp-OutputArea-child
+                    //     jp-OutputArea-output *
+                    //     widgets-output *
+                    //     jp-OutputArea *
+                    //     jp-OutputArea-child
+                    //     jp-OutputArea-output *
                     let ptr = el;
                     while (!ptr.parent().hasClass("jp-Cell-outputArea")) {
                         ptr.css('overflow-x', 'auto');
@@ -102,6 +102,8 @@ class DataTable(WidgetWrapper):
         self.el_auxiliaries = [self.tunnel, Javascript(jscode)]
         self.init_complete = False
         self.init_complete_callback = noarg_func
+        self.on_draw_callback = noarg_func
+        self.on_redraw_callback = noarg_func
 
     @property
     def widget(self):
@@ -128,6 +130,12 @@ class DataTable(WidgetWrapper):
     def on_init_complete(self, callback = None):
         self.init_complete_callback = callback or noarg_func
 
+    def on_draw(self, callback = None):
+        self.on_draw_callback = callback
+
+    def on_redraw(self, callback = None):
+        self.on_redraw_callback = callback
+
     def on_receive_updates(self, version: int, msg: str):
         msg = ujson.loads(msg)
         if msg['type'] == 'query':
@@ -138,10 +146,14 @@ class DataTable(WidgetWrapper):
                 "data":  self.df[msg['start']:msg['start']+msg['length']].values.tolist()
             }
             self.tunnel.send_msg_with_version(version, ujson.dumps(resp))
-        elif msg['type'] == 'handshake':
+        elif msg['type'] == 'status':
             msg = msg['msg']
-            if msg == 'init_start':
-                pass
-            elif msg == 'init_done':
+            if msg == 'init_done':
                 self.init_complete = True
-                self.init_complete_callback()
\ No newline at end of file
+                self.init_complete_callback()
+                self.on_draw_callback()
+            elif msg == 'redraw':
+                self.on_draw_callback()
+                self.on_redraw_callback()
+            # elif msg == 'init_start':
+            #     pass
\ No newline at end of file
